@@ -1,4 +1,5 @@
-bisection.update <- function(ModelMx, ObsTbl, tolerance)
+bisection.update <-
+function(ModelMx, ObsTbl, tolerance)
 {
    obs.s <- sum(ObsTbl);
    b <- suff.stat(ModelMx, ObsTbl/obs.s);
@@ -28,4 +29,4 @@ bisection.update <- function(ModelMx, ObsTbl, tolerance)
     bisection.result <- list(gamma.tilde =  gamma.mid,
                              model.tilde =  F.gamma.mid); 
     return(bisection.result);
-}
\ No newline at end of file
+}
