@@ -3,13 +3,13 @@ function(ModelMatrix, ObsTable, tol, estimand, adjustment)
 {
   nc <- ncol(ModelMatrix);
   nr <- nrow(ModelMatrix);
-  if(sum(ObsTable == 0)>0) 
+  if(sum(ObsTable == 0)>0)
      warning("Some of the observed values are zero; the model parameters may not be identifiable");
-  if(length(ObsTable) != nc) 
+  if(length(ObsTable) != nc)
      stop("Dimensions of the model matrix and the data vector do not match");
   est <- (estimand == "probabilities") + (estimand == "intensities");
   if( est != 1) stop("The estimand is not specified correctly.")
-  adj <- (adjustment == "grid") + (adjustment == "bisection") + 
+  adj <- (adjustment == "grid") + (adjustment == "bisection") +
          (adjustment == "none");
   if( adj != 1) stop("The adjustment method is not specified correctly.")
 
@@ -19,53 +19,49 @@ function(ModelMatrix, ObsTable, tol, estimand, adjustment)
   if (estimand == "intensities")
   {
      F <- ipf.gamma(ModelMatrix, ObsTable, 1, tol, "intensities");
-     mleTable <- round(F$fitted.values,2);
-     model.parameters <- round(F$model.parameters,2);
-     }  else   {      
+     mleTable <- round(F$fitted.values,4);
+     model.parameters <- round(F$model.parameters,4);
+     iter <- F$iterations;
+   }  else   {
      F <- ipf.gamma(ModelMatrix, ObsTable, 1, tol, "probabilities")
-     p <- F$fitted.values; 
+     p <- F$fitted.values;
      model.parameters <- F$parameters;
-     p.sum <- sum(p); 
+     p.sum <- sum(p);
      obs.sum <- sum(ObsTable);
      Total <- p.sum/obs.sum;
      gamma.hat <- 1;
      if (abs(Total - 1) > tol)
-     { 
+     {
            b <- suff.stat(ModelMatrix, ObsTable/obs.sum);
-           
            gamma.left <- 1/(sum(b));
-           gamma.right <- min(1/b); 
-           if( adjustment == "grid")
+           gamma.right <- min(1/b); print(gamma.right)
+           if( adj == "grid")
            {
                UpdateGamma <-  grid.update(ModelMatrix, ObsTable, tol)
-                                
            }
            else
            {
-               UpdateGamma <- bisection.update(ModelMatrix, ObsTable, tol) 
+               UpdateGamma <- bisection.update(ModelMatrix, ObsTable, tol)
            }
 
-     
-          
-             
+
            F <- UpdateGamma$model.tilde;
            gamma.hat <- UpdateGamma$gamma.tilde;  
          }
-        model.parameters <- F$model.parameters; 
+        model.parameters <- F$model.parameters;
         mleTable <- round(F$fitted.values,4);
+       # gamma.hat <- gamma.mid
       }
       chisqv <-  sum( (ObsTable-mleTable)^2/mleTable);
       LLratio <- 0;
-         
-      for(i in 1:nc)
-      {
-         if(ObsTable[i] > 0) 
-           {LLratio <- LLratio + ObsTable[i]*log(ObsTable[i]/mleTable[i])};
-      }
-      LLratio <- 2*LLratio;
+
+      ObsTablePositive <- ObsTable[ObsTable>0]
+      mleTablePositive <- mleTable[ObsTable>0]
+      LLratio <- 2*(sum(ObsTablePositive*log(ObsTablePositive/mleTablePositive)) -
+                    sum(ObsTable - mleTable));
 
       df <- nc - qr(ModelMatrix)$rank;
-      pv1 <- 1-pchisq(chisqv,df); 
+      pv1 <- 1-pchisq(chisqv,df);
       pv2 <- 1-pchisq(LLratio,df);
 
       if(estimand == "probabilities")
@@ -73,8 +69,8 @@ function(ModelMatrix, ObsTable, tol, estimand, adjustment)
          result <- list(model.matrix = ModelMatrix,
                      observed.data = ObsTable,
                      fitted.values = mleTable,
-                     adjustment.for.subsets = round(gamma.hat,4), 
-                     model.parameters = round(model.parameters,4), 
+                     adjustment.for.subsets = round(gamma.hat,4),
+                     model.parameters = round(model.parameters,4),
                      degrees.of.freedom = df,
                      chisq.statistic = round(chisqv,2),
                      p.value.chisq = round(pv1,2),
@@ -83,33 +79,18 @@ function(ModelMatrix, ObsTable, tol, estimand, adjustment)
       }
       else
       {
-           if (sum(mleTable)==sum(ObsTable))
-           {
-              result <- list(model.matrix = ModelMatrix,
+          result <- list(model.matrix = ModelMatrix,
                         observed.data = ObsTable,
                         fitted.values = mleTable,
                         estimated.total = sum(mleTable),
-                        adjustment.for.total = 1, 
-                        model.parameters = round(model.parameters,4), 
+                        adjustment.for.total = 1,
+                        model.parameters = round(model.parameters,4),
                         degrees.of.freedom = df,
                         chisq.statistic = round(chisqv,2),
                         p.value.chisq = round(pv1,2),
-                        log.likelihood.ratio.statistic = round(LLratio,2),
-                        p.value.log.likelihood.ratio = round(pv2,2))
-           }
-           else
-           {  
-              warning("No p-values are produced. The distributions of the chisq statistic and the log likelihood ratio statistic are unknown");
-              result <- list(model.matrix = ModelMatrix,
-                        observed.data = ObsTable,                        fitted.values = mleTable,
-                        estimated.total = sum(mleTable),
-                        adjustment.for.total = round(sum(mleTable)/sum(ObsTable),4), 
-                        model.parameters = round(model.parameters,4), 
-                        degrees.of.freedom = df,
-                        chisq.statistic = round(chisqv,2),
-                        log.likelihood.ratio.statistic = round(LLratio,2))
-            }
+                        Bregman.statistic = round(LLratio,2),
+                        p.value.Bregman.statistic = round(pv2,2))
+
       }
    return(result)
 }
-
