@@ -1,4 +1,5 @@
-grid.update <- function(ModelMx, ObsTbl, tolerance)
+grid.update <-
+function(ModelMx, ObsTbl, tolerance)
 {
    
    T <- 1;
@@ -47,4 +48,4 @@ grid.update <- function(ModelMx, ObsTbl, tolerance)
     grid.result <- list(gamma.tilde =  gamma.star,
                              model.tilde =  F.star); 
     return(grid.result);
-}
\ No newline at end of file
+}
